@@ -76,7 +76,11 @@ impl Selectable for CloseSelector {
     fn select<M: HirMode + TypedTrait>(&self, hir: &Hir<M>, sref: SRef) -> bool {
         assert!(sref.is_output());
         let output = hir.output(sref).unwrap();
-        let close_ty: Option<HirType> = output.instance_template.close.map(|eid| hir.expr_type(eid));
+        let close_ty: Option<HirType> = output
+            .instance_template
+            .close
+            .as_ref()
+            .map(|ct| hir.expr_type(ct.target));
         match self {
             CloseSelector::Any => true,
             CloseSelector::Closed => close_ty.is_some(),
@@ -347,11 +351,8 @@ impl<'a, M: HirMode + TypedTrait> StreamSelector<'a, M, Dynamic> {
 
 #[cfg(test)]
 mod tests {
-    use std::path::PathBuf;
-
     use itertools::Itertools;
     use rtlola_parser::ParserConfig;
-    use rtlola_reporting::Handler;
 
     use super::*;
     use crate::CompleteMode;
@@ -374,11 +375,10 @@ mod tests {
             output f (p: Int8) spawn @1Hz with i.aggregate(over:1s, using: sum) close i = 8 := i\n\
             output g filter i = 5 := i + 5";
 
-        let handler = Handler::new(PathBuf::new(), spec.into());
         let ast = ParserConfig::for_string(spec.into())
             .parse()
-            .unwrap_or_else(|e| panic!("{}", e));
-        let hir = crate::fully_analyzed(ast, &handler).expect("Invalid Spec");
+            .unwrap_or_else(|e| panic!("{:?}", e));
+        let hir = crate::fully_analyzed(ast).expect("Invalid Spec");
         hir
     }
 
